
#  Scores file name
SCORES_FILE_NAME = 'Scores.txt'
# score label in the file
SCORES_LABEL = "score"
# A number representing a bad return code for a function.
BAD_RETURN_CODE = -1

GOOD_RETURN_CODE = 0